==> cms_content_sync-8.x-1.33.tar.gz: cms_content_sync/modules/cms_content_sync_views/src/Plugin/Action/PullStatusEntity.php <==
<?php

namespace Drupal\cms_content_sync_views\Plugin\Action;

use Drupal\cms_content_sync\Entity\Flow;
use Drupal\cms_content_sync\PullIntent;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Pull entity of status entity.
 *
 * @Action(
 *   id = "import_status_entity",
 *   label = @Translation("Force Pull"),
 *   type = "cms_content_sync_entity_status"
 * )
 */
class PullStatusEntity extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    /** @var \Drupal\cms_content_sync\Entity\EntityStatus $entity */
    if (!is_null($entity)) {
      $source = $entity->getEntity();
      if (empty($source)) {
        \Drupal::messenger()->addMessage(t('The Entity @type @uuid doesn\'t exist locally, pull skipped.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '@uuid' => $entity->get('entity_uuid')->getValue()[0]['value'],
        ]), 'warning');
        return;
      }

      $pool = $entity->getPool();
      if (empty($pool)) {
        \Drupal::messenger()->addMessage(t('The Pool for @type %label doesn\'t exist anymore, push skipped.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '%label' => $source->label(),
        ]), 'warning');
        return;
      }

      $entity_type_name = $source->getEntityTypeId();
      $entity_bundle = $source->bundle();

      $manual = FALSE;

      $flow = Flow::getFlowForApiAndEntityType($pool, $entity_type_name, $entity_bundle, PullIntent::PULL_AUTOMATICALLY);
      if (!$flow) {
        $flow = Flow::getFlowForApiAndEntityType($pool, $entity_type_name, $entity_bundle, PullIntent::PULL_MANUALLY);
        if ($flow) {
          $manual = TRUE;
        }
        else {
          $flow = Flow::getFlowForApiAndEntityType($pool, $entity_type_name, $entity_bundle, PullIntent::PULL_AS_DEPENDENCY);
          if (!$flow) {
            \Drupal::messenger()->addMessage(t('No Flow exists to pull @type %label, pull skipped.', [
              '@type' => $entity->get('entity_type')->getValue()[0]['value'],
              '%label' => $source->label(),
            ]), 'warning');
            return;
          }
        }
      }

      /**
       * @var \Drupal\cms_content_sync\SyncCore\Entity\ConnectionSynchronization $sync
       */
      $sync = $pool->getConnectionSynchronizationForEntityType(
        $entity_type_name,
        $entity_bundle,
        $entity->getEntityTypeVersion(),
        FALSE
      );

      if ($source instanceof ConfigEntityInterface) {
        $shared_entity_id = $source->id();
      }
      else {
        $shared_entity_id = $source->uuid();
      }

      $action = $sync->synchronizeSingle($shared_entity_id);

      if ($manual) {
        $action->isManual(TRUE);
      }

      $success = $action
        ->execute()
        ->succeeded();

      if ($success) {
        \Drupal::messenger()->addMessage(t('Pull of @type %label has been triggered.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '%label' => $source->label(),
        ]));
      }
      else {
        \Drupal::messenger()->addMessage(t('Pull of @type %label couldn\'t be triggered.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '%label' => $source->label(),
        ]), 'warning');
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    return TRUE;
  }

}

==> cms_content_sync-8.x-1.34.tar.gz: cms_content_sync/modules/cms_content_sync_views/src/Plugin/Action/PullStatusEntity.php <==
<?php

namespace Drupal\cms_content_sync_views\Plugin\Action;

use Drupal\cms_content_sync\Entity\Flow;
use Drupal\cms_content_sync\PullIntent;
use Drupal\cms_content_sync\SyncCore\Exception\SyncCoreException;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Pull entity of status entity.
 *
 * @Action(
 *   id = "import_status_entity",
 *   label = @Translation("Force Pull"),
 *   type = "cms_content_sync_entity_status"
 * )
 */
class PullStatusEntity extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    /** @var \Drupal\cms_content_sync\Entity\EntityStatus $entity */
    if (!is_null($entity)) {
      $source = $entity->getEntity();
      if (empty($source)) {
        \Drupal::messenger()->addMessage(t('The Entity @type @uuid doesn\'t exist locally, pull skipped.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '@uuid' => $entity->get('entity_uuid')->getValue()[0]['value'],
        ]), 'warning');
        return;
      }

      $pool = $entity->getPool();
      if (empty($pool)) {
        \Drupal::messenger()->addMessage(t('The Pool for @type %label doesn\'t exist anymore, push skipped.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '%label' => $source->label(),
        ]), 'warning');
        return;
      }

      $entity_type_name = $source->getEntityTypeId();
      $entity_bundle = $source->bundle();

      $manual = FALSE;

      $flow = Flow::getFlowForApiAndEntityType($pool, $entity_type_name, $entity_bundle, PullIntent::PULL_AUTOMATICALLY);
      if (!$flow) {
        $flow = Flow::getFlowForApiAndEntityType($pool, $entity_type_name, $entity_bundle, PullIntent::PULL_MANUALLY);
        if ($flow) {
          $manual = TRUE;
        }
        else {
          $flow = Flow::getFlowForApiAndEntityType($pool, $entity_type_name, $entity_bundle, PullIntent::PULL_AS_DEPENDENCY);
          if (!$flow) {
            \Drupal::messenger()->addMessage(t('No Flow exists to pull @type %label, pull skipped.', [
              '@type' => $entity->get('entity_type')->getValue()[0]['value'],
              '%label' => $source->label(),
            ]), 'warning');
            return;
          }
        }
      }

      if ($source instanceof ConfigEntityInterface) {
        $shared_entity_id = $source->id();
      }
      else {
        $shared_entity_id = $source->uuid();
      }

      try {
        $pool
          ->getClient()
          ->getSyndicationService()
          ->pullSingle($flow->id, $entity_type_name, $entity_bundle, $shared_entity_id)
          ->fromPool($pool->id)
          ->manually(!!$manual)
          ->execute();

        \Drupal::messenger()->addMessage(t('Pull of @type %label has been triggered.', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '%label' => $source->label(),
        ]));
      }
      catch (SyncCoreException $e) {
        \Drupal::messenger()->addMessage(t('Failed to pull @type %label: @message', [
          '@type' => $entity->get('entity_type')->getValue()[0]['value'],
          '%label' => $source->label(),
          '@message' => $e->getMessage(),
        ]), 'warning');
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    return TRUE;
  }

}
